@@ -55,11 +55,11 @@ exports.useUtils = function ( ) {
       useBower  = locations[ 0 ].name === "frontend";
     }
 
-    locations = locations.filter( function ( location ) {
+    var _locations = locations.filter( function ( location ) {
       return ( useNPM && useBower ) || ( useNPM && location.name === "backend" ) || ( useBower && location.name === "frontend" );
     } );
 
-    def.resolve( [ locations, useNPM, useBower ] );
+    def.resolve( [ _locations, useNPM, useBower ] );
   } );
 
   return def.promise;
@@ -231,8 +231,6 @@ var findGruntFile = exports.findGruntFile = function ( pathSrc ) {
 var find = exports.find = function( ) {
   var def = Promise.defer( );
 
-  utils.info( 'Scanning for seed locations...' );
-
   // As of right now... our best bet is to look forward once
   // and then backwards first match. The limitation of this
   // is that we're presuming the folders are called backend and frontend
@@ -327,6 +325,99 @@ var locations = exports.location = exports.locations = function ( useCWD, fn ) {
   return def.promise;
 }
 
+/**
+ * Runs grunt readme if applicable
+ *
+ * @param  {String} projectFolder  Path to the project's folder
+ * @return {Promise}               Returns a promise from bluebird
+ * @api private
+ */
+
+function runReadMe ( projectFolder ) {
+  var def   = Promise.defer( )
+    , args  = [ '--base', projectFolder, '--gruntfile', path.resolve( path.join( projectFolder, 'Gruntfile.js' ) ), 'readme' ]
+    , proc  = spawn( 'grunt', args, { cwd: projectFolder, stdio: 'inherit' } );
+
+  proc.on( 'close', function ( code ) {
+    if (code !== 0) {
+      return def.reject( );
+    }
+
+    def.resolve( );
+  } );
+
+  return def.promise;
+}
+
+/**
+ * Runs prompt from Grunt (prompt:clever)
+ *
+ * @param  {String} projectFolder Path to the project's/module's folder
+ * @return {Promise}              Returns a promise from bluebird
+ * @api private
+ */
+
+function runPrompt ( projectFolder ) {
+  var env   = process.env
+    , def   = Promise.defer( )
+    , args  = [ '--base', projectFolder, '--gruntfile', path.resolve( path.join( projectFolder, 'Gruntfile.js' ) ), 'prompt:clever' ];
+
+  var proc = spawn( 'grunt', args, { cwd: projectFolder, stdio: 'inherit' } );
+
+  proc.on( 'close', function ( code ) {
+    if (code !== 0) {
+      return def.reject( );
+    }
+
+    def.resolve( );
+  } );
+
+  return def.promise;
+}
+
+/**
+ * Runs DB migrations from grunt
+ *
+ * @param  {String} projectFolder Path to the project's folder
+ * @return {Promise}              Returns a promise from bluebird
+ * @api private
+ */
+
+function runDBMigrations ( projectFolder ) {
+  var def = Promise.defer( );
+
+  utils.warn( 'Running database migrations...' );
+
+  var args = [ '--base', projectFolder, '--gruntfile', path.resolve( path.join( projectFolder, 'Gruntfile.js' ) ), 'db' ]
+    , env  = process.env;
+
+  // check for NODE_ENV json config file if it doesn't exist then revert to local
+  if (!fs.existsSync( path.join( projectFolder, 'config', env.NOD_ENV + '.json') ) ) {
+    env.NODE_ENV  = 'local';
+  }
+
+  var proc = spawn( 'grunt', args, { env: env, cwd: projectFolder } )
+    , _err = '';
+
+  proc.stderr.on('data', function ( data ) {
+    _err += data + '';
+  } );
+
+  proc.stdout.on('data', function ( data ) {
+    // console.log(data + '');
+  } );
+
+  proc.on( 'close', function ( code ) {
+    if (code !== 0) {
+      return def.reject( _err );
+    }
+
+    def.resolve( true );
+  } );
+
+  return def.promise;
+}
+
 /**
  * Looks into packahe.json within the seed's module directory
  * and finds each (dev)dependency and installs individually
@@ -387,34 +478,31 @@ exports.installModule = function ( project, modulePath ) {
     // backend folder?
     if (!fs.existsSync( bowerPath ) ) {
       // do we need to run db migrations?
-      readGruntTasks( moduleDir )
+      readGruntTasks( modulePath )
       .spread( function ( tasks, __path__ ) {
-        if (tasks.indexOf( 'db:exec' ) === -1) {
-          return def.resolve( );
-        }
-
-        utils.warn( 'Running database migrations...' );
-
-        var args = [ '--base', projectFolder, '--gruntfile', path.resolve( path.join( projectFolder, 'Gruntfile.js' ) ), 'db:exec' ]
-          , env  = process.env;
-
-        // check for NODE_ENV json config file if it doesn't exist then revert to local
-        if (!fs.existsSync( path.join( projectFolder, 'config', env.NOD_ENV + '.json') ) ) {
-          env.NODE_ENV  = 'local';
-        }
-
-        var proc = spawn( 'grunt', args, { env: env, cwd: projectFolder } );
-
-        proc.stderr.on('data', function ( data ) {
-          _err += data + '';
-        } );
-
-        proc.on( 'close', function ( code ) {
-          if (code !== 0) {
-            return def.reject( _err );
+        Promise.all( tasks )
+        .then( function ( ) {
+          if (tasks.indexOf( 'readme') > -1) {
+            return runReadMe( projectFolder );
           }
-
-          def.resolve( true );
+          return true;
+        } )
+        .then( function ( ) {
+          if (tasks.indexOf( 'prompt:clever' ) > -1) {
+            return runPrompt( projectFolder );
+          }
+          return true;
+        } )
+        .then( function ( ) {
+          if (tasks.indexOf( 'db' ) > -1) {
+            runDBMigrations( projectFolder );
+          }
+          return true;
+        } )
+        .then( function ( ) {
+          def.resolve( );
+        }, function ( err ) {
+          def.reject( err );
         } );
       } );
     } else {
